"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReactShortcutProvider = void 0;
const react_1 = require("react");
const shortcut_context_1 = require("./shortcut-context");
const shortcut_registry_1 = require("./shortcut-registry");
const ReactShortcutProvider = function ReactShortcutProvider(props) {
    const { children, options: { strict = true, debug = false, filter, scope } = {} } = props;
    const shortcutRegistry = (0, react_1.useMemo)(() => {
        return new shortcut_registry_1.ShortcutRegistry({ strict, debug, filter });
    }, []);
    const contextValue = (0, react_1.useMemo)(() => {
        return {
            registerShortcut: shortcutRegistry.registerShortcut.bind(shortcutRegistry),
            unregisterShortcut: shortcutRegistry.unregisterShortcut.bind(shortcutRegistry),
            enableShortcut: shortcutRegistry.enableShortcut.bind(shortcutRegistry),
            disableShortcut: shortcutRegistry.disableShortcut.bind(shortcutRegistry),
            isShortcutRegistered: shortcutRegistry.isShortcutRegistered.bind(shortcutRegistry),
            getCurrentKeyPressed: shortcutRegistry.getCurrentKeyPressed.bind(shortcutRegistry),
            onKeydown: shortcutRegistry.onKeydown.bind(shortcutRegistry),
            onKeyup: shortcutRegistry.onKeyup.bind(shortcutRegistry),
        };
    }, [scope === null || scope === void 0 ? void 0 : scope.current]);
    (0, react_1.useEffect)(() => {
        if (!scope) {
            return shortcutRegistry.attachElement(window);
        }
        else if (scope.current) {
            return shortcutRegistry.attachElement(scope.current);
        }
    }, [scope === null || scope === void 0 ? void 0 : scope.current]);
    return <shortcut_context_1.ReactShortcutContext.Provider value={contextValue}>{children}</shortcut_context_1.ReactShortcutContext.Provider>;
};
exports.ReactShortcutProvider = ReactShortcutProvider;
exports.ReactShortcutProvider.displayName = 'ReactShortcutProvider';
//# sourceMappingURL=shortcut-provider.jsx.map