import { keyCodeName2KeyCode } from './key-codes';
import { isEmpty } from './utils';
export class AcceleratorParser {
    static keyCodeNameIsModifiers(keycode) {
        return AcceleratorParser.ModifierKeyCodeNames.has(keycode);
    }
    parseAccelerator(accelerator) {
        // remove all space
        accelerator = accelerator.replaceAll(/\s/gi, '');
        const keyCodeNames = accelerator.split(AcceleratorParser.separator);
        let position = 0;
        const modifiers = [];
        const normalKeys = [];
        for (let i = 0; i < keyCodeNames.length; i++) {
            // resolve alias
            let keyCodeName = keyCodeNames[i];
            if (keyCodeName === '') {
                if (keyCodeNames[i + 1] === '') {
                    keyCodeNames[i] = AcceleratorParser.separator;
                    keyCodeNames.splice(i + 1, 1);
                    keyCodeName = keyCodeNames[i];
                }
                else {
                    throwParseError(position);
                }
            }
            if (!keyCodeName2KeyCode.has(keyCodeName)) {
                throwParseError(position);
            }
            if (AcceleratorParser.keyCodeNameIsModifiers(keyCodeName)) {
                if (!isEmpty(normalKeys)) {
                    throwParseError(position + 1);
                }
                modifiers.push(keyCodeName);
            }
            else {
                normalKeys.push(keyCodeName);
            }
            position += keyCodeName.length + 1;
        }
        return [
            modifiers
                .reduce((prev, item) => {
                const next = [];
                const keyCodes = keyCodeName2KeyCode.get(item);
                keyCodes.forEach((keycode) => {
                    prev.forEach((resolved) => {
                        next.push([...resolved, keycode]);
                    });
                });
                return next;
            }, [[]])
                .map((item) => item.sort().join(AcceleratorParser.separator)),
            normalKeys
                .reduce((prev, item) => {
                const next = [];
                const keyCodes = keyCodeName2KeyCode.get(item);
                keyCodes.forEach((keycode) => {
                    prev.forEach((resolved) => {
                        next.push([...resolved, keycode]);
                    });
                });
                return next;
            }, [[]])
                .map((item) => item.join(AcceleratorParser.separator)),
        ];
        function throwParseError(position) {
            throw new Error(`parse accelerator failed in position ${position}.`);
        }
    }
}
AcceleratorParser.ModifierKeyCodeNames = new Set([
    'ControlOrCommand',
    'Ctrl',
    'CtrlLeft',
    'CtrlRight',
    'Control',
    'ControlLeft',
    'ControlRight',
    'Shift',
    'ShiftLeft',
    'ShiftRight',
    'Option',
    'OptionLeft',
    'OptionRight',
    'Alt',
    'AltLeft',
    'AltRight',
    'Command',
    'CommandLeft',
    'CommandRight',
    'Meta',
    'MetaLeft',
    'MetaRight',
]);
AcceleratorParser.separator = '+';
//# sourceMappingURL=accelerator-parser.js.map