import { useEffect, useMemo } from 'react';
import { ReactShortcutContext } from './shortcut-context';
import { ShortcutRegistry } from './shortcut-registry';
export const ReactShortcutProvider = function ReactShortcutProvider(props) {
    const { children, options: { strict = true, debug = false, filter, scope } = {} } = props;
    const shortcutRegistry = useMemo(() => {
        return new ShortcutRegistry({ strict, debug, filter });
    }, []);
    const contextValue = useMemo(() => {
        return {
            registerShortcut: shortcutRegistry.registerShortcut.bind(shortcutRegistry),
            unregisterShortcut: shortcutRegistry.unregisterShortcut.bind(shortcutRegistry),
            enableShortcut: shortcutRegistry.enableShortcut.bind(shortcutRegistry),
            disableShortcut: shortcutRegistry.disableShortcut.bind(shortcutRegistry),
            isShortcutRegistered: shortcutRegistry.isShortcutRegistered.bind(shortcutRegistry),
            getCurrentKeyPressed: shortcutRegistry.getCurrentKeyPressed.bind(shortcutRegistry),
            onKeydown: shortcutRegistry.onKeydown.bind(shortcutRegistry),
            onKeyup: shortcutRegistry.onKeyup.bind(shortcutRegistry),
        };
    }, [scope === null || scope === void 0 ? void 0 : scope.current]);
    useEffect(() => {
        if (!scope) {
            return shortcutRegistry.attachElement(window);
        }
        else if (scope.current) {
            return shortcutRegistry.attachElement(scope.current);
        }
    }, [scope === null || scope === void 0 ? void 0 : scope.current]);
    return <ReactShortcutContext.Provider value={contextValue}>{children}</ReactShortcutContext.Provider>;
};
ReactShortcutProvider.displayName = 'ReactShortcutProvider';
//# sourceMappingURL=shortcut-provider.jsx.map